package com.sun.jmx.snmp.IPAcl;

import java.util.Vector;
import java.net.InetAddress;
import java.util.Hashtable;
import java.security.acl.NotOwnerException;
import java.util.logging.Level;
import com.sun.jmx.defaults.JmxProperties;
import java.net.UnknownHostException;
import java.io.Serializable;

abstract class Host extends SimpleNode implements Serializable
{
    public Host(int n) {
        super(n);
    }
    
    public Host(Parser parser, int n) {
        super(parser, n);
    }
    
    protected abstract PrincipalImpl createAssociatedPrincipal() throws UnknownHostException;
    
    protected abstract String getHname();
    
    @Override
    public void buildAclEntries(PrincipalImpl principalImpl, AclImpl aclImpl) {
        PrincipalImpl associatedPrincipal;
        try {
            associatedPrincipal = this.createAssociatedPrincipal();
        }
        catch (UnknownHostException thrown) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, Host.class.getName(), "buildAclEntries", "Cannot create ACL entry; got exception", thrown);
            }
            throw new IllegalArgumentException("Cannot create ACL entry for " + thrown.getMessage());
        }
        try {
            AclEntryImpl aclEntryImpl = new AclEntryImpl(associatedPrincipal);
            this.registerPermission(aclEntryImpl);
            aclImpl.addEntry(principalImpl, aclEntryImpl);
        }
        catch (UnknownHostException thrown2) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, Host.class.getName(), "buildAclEntries", "Cannot create ACL entry; got exception", thrown2);
            }
            return;
        }
        catch (NotOwnerException thrown3) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, Host.class.getName(), "buildAclEntries", "Cannot create ACL entry; got exception", thrown3);
            }
            return;
        }
    }
    
    private void registerPermission(AclEntryImpl aclEntryImpl) {
        JDMAclItem jdmAclItem = (JDMAclItem)((JDMManagers)((JDMHost)this.jjtGetParent()).jjtGetParent()).jjtGetParent();
        jdmAclItem.getAccess().putPermission(aclEntryImpl);
        jdmAclItem.getCommunities().buildCommunities(aclEntryImpl);
    }
    
    @Override
    public void buildTrapEntries(Hashtable<InetAddress, Vector<String>> hashtable) {
        String community = ((JDMTrapItem)((JDMTrapInterestedHost)((JDMHostTrap)this.jjtGetParent()).jjtGetParent()).jjtGetParent()).getCommunity().getCommunity();
        InetAddress byName;
        try {
            byName = InetAddress.getByName(this.getHname());
        }
        catch (UnknownHostException thrown) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, Host.class.getName(), "buildTrapEntries", "Cannot create TRAP entry; got exception", thrown);
            }
            return;
        }
        if (hashtable.containsKey(byName)) {
            Vector<String> vector = (Vector)hashtable.get(byName);
            if (!vector.contains(community)) {
                vector.addElement(community);
            }
        }
        else {
            Vector<String> value = new Vector();
            value.addElement(community);
            hashtable.put(byName, value);
        }
    }
    
    @Override
    public void buildInformEntries(Hashtable<InetAddress, Vector<String>> hashtable) {
        String community = ((JDMInformItem)((JDMInformInterestedHost)((JDMHostInform)this.jjtGetParent()).jjtGetParent()).jjtGetParent()).getCommunity().getCommunity();
        InetAddress byName;
        try {
            byName = InetAddress.getByName(this.getHname());
        }
        catch (UnknownHostException thrown) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, Host.class.getName(), "buildTrapEntries", "Cannot create INFORM entry; got exception", thrown);
            }
            return;
        }
        if (hashtable.containsKey(byName)) {
            Vector<String> vector = (Vector)hashtable.get(byName);
            if (!vector.contains(community)) {
                vector.addElement(community);
            }
        }
        else {
            Vector<String> value = new Vector();
            value.addElement(community);
            hashtable.put(byName, value);
        }
    }
}
